# -*- coding: UTF-8 -*-
"""
@Project ：pydmdll
@File ：__init__.py.py
@Author ：Gao yongxian
@Date ：2021/10/24 15:52
@contact: g1695698547@163.com
"""
from .damo import *
name = "pydmdll"